@@ -9,17 +9,13 @@ def main():
   print 'Creating vision dataset for Caltech101 dataset'
   dbfile = Caltech101().export()
   print 'Exporting Caltech101 dataset to redistributable HDF5 file "' + dbfile + '"'
-  
-  # Import an existing viset 
-  print 'Displaying training/testing split in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile, split='2fold')
-  for (im,annotation) in db['train']:
-    print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    imshow(im, title=annotation['category'])
-  for (im,annotation) in db['test']:
-    print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    imshow(im, title=annotation['category'])
 
+  # Show dataset
+  print 'Displaying viset (VISion dataSET) "' + dbfile + '"'
+  for (im,annotation) in Viset(dbfile, datastep=100, async=False)[0]:
+    print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
+    imshow(im)
+  
   # Cleanup cached data (optional)
   # db.delete()
   
