@@ -21,11 +21,6 @@ import datetime
 from viset.cache import Cache
 
 
-class AboutTable(tables.IsDescription):
-    viset = tables.StringCol(256, pos=0)   
-    name = tables.StringCol(256, pos=1)   
-    version = tables.Int64Col(pos=2)   
-
 class SplitTable(tables.IsDescription):
     split0 = tables.UInt8Col(pos=0)   
     split1 = tables.UInt8Col(pos=1)   
@@ -156,25 +151,27 @@ class Viset(object):
         # Open in read mode
         try:
             quietprint('Opening viset "' + dbfile + '"', self.verbose)
-            dbobj = tables.open_file(dbfile, mode = "r")
-            if not viset.util.isurl(dbobj.root.about[0]['viset']):
+            self.dbobj = tables.open_file(dbfile, mode = "r")
+            if not self.isviset():
                 raise IOError()        
         except:
             print 'Invalid database file "' + str(dbfile) + '"'
+            self.close()
             raise      
 
         # Update class properties
-        self.dbobj = dbobj
         self.dbfile = dbfile
         self.dburl = dburl
         return self.dbobj
     
-    def create(self, view=_viewname):
+    def create(self, view=None):
         dbfile = self.dbcache.abspath(self._dbname+'.h5')
         dburl = None
         quietprint('Creating viset "' + dbfile + '"', self.verbose)                
         
         # Format new dataset
+        if view is None:
+            view = self._viewname
         self.dbobj = self.format(dbfile, self._dbname, view, self._version)
 
         # Create default view
@@ -185,20 +182,29 @@ class Viset(object):
         self.dburl = dburl
         
     def close(self):
-        self.dbobj.close()
+        if self.dbobj is not None:
+            self.dbobj.close()
+            del(self.dbobj)
 
     def delete(self):
         self.dbcache.delete()
 
     def name(self):
-        return self.dbobj.root.about[0]['name']
+        return self.dbobj.root._v_attrs.viset_name        
   
     def version(self):
-        return self.dbobj.root.about[0]['version']
-
-    def about(self):
-        return self.dbobj.root.about[0]
+        return self.dbobj.root._v_attrs.viset_version
 
+    def isviset(self):
+        try: 
+            if self.dbobj.root._v_attrs.viset == 'http://www.visym.com':
+                return True
+            else:
+                return False
+        except:
+            # does not contain required attribute
+            return False
+        
     def list_views(self):
         """List of views in database"""    
         viewlist = []
@@ -245,7 +251,6 @@ class Viset(object):
     def format(self, dbfile, dbname, dbviewname=[], dbversion=0):
         # HDF5 file structure
         self.dbobj = tables.open_file(dbfile, mode = "w", title = dbname)
-        tbl_about = self.dbobj.create_table(self.dbobj.root, 'about', AboutTable, expectedrows=1, title='About')    
         tbl_splits = self.dbobj.create_table(self.dbobj.root, 'splits', SplitTable, title='Splits', expectedrows=1000000)
         tbl_images = self.dbobj.create_table(self.dbobj.root, 'images', ImageTable, title='Images', filters=tables.Filters(complevel=6), expectedrows=1000000)
     
@@ -257,11 +262,9 @@ class Viset(object):
             tbl_anno.flush()
       
         # Metadata
-        r = tbl_about.row
-        r['viset'] = 'http://www.visym.com'
-        r['version'] = dbversion
-        r['name'] = dbname
-        r.append()
+        self.dbobj.root._v_attrs.viset = 'http://www.visym.com'
+        self.dbobj.root._v_attrs.viset_version = dbversion
+        self.dbobj.root._v_attrs.viset_name = dbname
 
         # Return newly created database for writing
         self.dbobj.flush()
