@@ -134,8 +134,8 @@ class CategorizationView(VisetView):
 
     def read(self, id_anno):
         id_img = self.dbtbl[id_anno]['id_img']
-        impath = self.db.dbobj.root.images[id_img]['url']
-        im = viset.types.Image(impath, cachedir=self.db.cachedir, verbose=self.db.verbose, imcodec=self.db.imcodec())
+        imurl = self.db.dbobj.root.images[id_img]['url']
+        im = viset.types.Image(imurl, cache=self.db.dbcache, verbose=self.db.verbose)
         anno = self.dbtbl[id_anno]
         if self.async:
             return (im,anno)  # numpy structured array tuple
@@ -189,7 +189,7 @@ class DetectionView(VisetView):
     def read(self, id_anno):
         id_img = self.dbtbl[id_anno]['id_img']
         impath = self.db.dbobj.root.images[id_img]['url']
-        im = viset.types.Image(impath, cachedir=self.db.cachedir, verbose=self.db.verbose, imcodec=self.db.imcodec())
+        im = viset.types.Image(impath, cache=self.db.dbcache, verbose=self.db.verbose)
         anno = self.dbtbl[id_anno]
         if self.async:
             return (im,anno)  # numpy structured array tuple
@@ -215,23 +215,29 @@ class SegmentationView(VisetView):
         tbl.flush()
         return tbl
         
-    def add_segmentation(self, url_mask, id_img, category=None):
+    def add_segmentation(self, relpath, id_img, category=None, url=None):
+        qs = {}
+        if relpath is not None:
+            qs['item'] = relpath
+        url_fragment = urlparse.unquote(urllib.urlencode(qs))
+        if len(url_fragment) > 0:
+            url = url + '#' + url_fragment
         if self._dbrow is None:
             self._dbrow = self.db.dbobj.root.annotation.segmentation.row
-        self._dbrow['mask'] = url_mask
+        self._dbrow['mask'] = url
         self._dbrow['id_img'] = id_img        
         self._dbrow['category'] = category  
         self._dbrow.append()
     
     def read(self, id_anno):
         id_img = self.dbtbl[id_anno]['id_img']
-        impath = self.db.dbobj.root.images[id_img]['url']	
-        im = viset.types.Image(impath, cachedir=self.db.cachedir, verbose=self.db.verbose, imcodec=self.db.imcodec())
-        maskpath = self.dbtbl[id_anno]['mask']
-        if maskpath == '':
+        imurl = self.db.dbobj.root.images[id_img]['url']	
+        im = viset.types.Image(imurl, cache=self.db.dbcache, verbose=self.db.verbose)
+        maskurl = self.dbtbl[id_anno]['mask']
+        if maskurl == '':
 			mask = None
         else:
-			mask = viset.types.Image(maskpath, cachedir=self.db.cachedir, verbose=self.db.verbose, imcodec=self.db.imcodec())
+			mask = viset.types.Image(maskurl, cache=self.db.dbcache, verbose=self.db.verbose)
         anno = self.dbtbl[id_anno]
         if self.async:
             anno = {'id_category':anno['id_category'], 'category':anno['category'], 'mask':mask}            
